@@ -1,5 +1,5 @@
 #define PY_SSIZE_T_CLEAN
-#include <Python.h>
+#include "Python.h"
 #include "pyobjc-api.h"
 
 #import <StoreKit/StoreKit.h>
@@ -9,22 +9,18 @@
  */
 #include "_StoreKit_protocols.m"
 
-
 static PyMethodDef mod_methods[] = {
-    { 0, 0, 0, 0 } /* sentinel */
+    {0, 0, 0, 0} /* sentinel */
 };
 
-
 /* Python glue */
 PyObjC_MODULE_INIT(_StoreKit)
 {
     PyObject* m;
-    m = PyObjC_MODULE_CREATE(_StoreKit)
-    if (!m) {
-        PyObjC_INITERROR();
-    }
+    m = PyObjC_MODULE_CREATE(_StoreKit) if (!m) { PyObjC_INITERROR(); }
 
-    if (PyObjC_ImportAPI(m) == -1) PyObjC_INITERROR();
+    if (PyObjC_ImportAPI(m) == -1)
+        PyObjC_INITERROR();
 
     PyObjC_INITDONE();
 }
